@@ -5,6 +5,7 @@ LC_ALL=C ; export LC_ALL
 echo '/* ISC license. */'
 echo
 echo '#include <skalibs/nonposix.h>'
+echo '#include <skalibs/bsdsnowflake.h>'
 echo
 { echo '#include <string.h>' ; echo '#include <stdlib.h>' ; cat src/execline/*.c | grep '^#include <' | grep -vF '<skalibs/' | grep -vF '<execline/' ; } | sort -u
 
@@ -17,6 +18,8 @@ cat <<EOF
 #include <execline/execline.h>
 #include "exlsn.h"
 
+#include <skalibs/posixishard.h>
+
 typedef int main_func (int, char **, char const *const *) ;
 typedef main_func *main_func_ref ;
 
